/*******************************************************************************
* File Name: UART_8bit_T1.h
* Version 2.10
*
* Description:
*  Contains the function prototypes and constants available to the UART
*  user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2011, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/


#include "cytypes.h"
#include "cyfitter.h"

#if !defined(CY_UART_UART_8bit_T1_H)
#define CY_UART_UART_8bit_T1_H


/***************************************
* Conditional Compilation Parameters
***************************************/

#define UART_8bit_T1_RX_ENABLED                     (1u)
#define UART_8bit_T1_TX_ENABLED                     (1u)
#define UART_8bit_T1_HD_ENABLED                     (0u)
#define UART_8bit_T1_RX_INTERRUPT_ENABLED           (0u)
#define UART_8bit_T1_TX_INTERRUPT_ENABLED           (0u)
#define UART_8bit_T1_INTERNAL_CLOCK_USED            (0u)
#define UART_8bit_T1_RXHW_ADDRESS_ENABLED           (0u)
#define UART_8bit_T1_OVER_SAMPLE_COUNT              (8u)
#define UART_8bit_T1_PARITY_TYPE                    (0u)
#define UART_8bit_T1_PARITY_TYPE_SW                 (0u)
#define UART_8bit_T1_BREAK_DETECT                   (0u)
#define UART_8bit_T1_BREAK_BITS_TX                  (13u)
#define UART_8bit_T1_BREAK_BITS_RX                  (13u)
#define UART_8bit_T1_TXCLKGEN_DP                    (1u)
#define UART_8bit_T1_USE23POLLING                   (0u)
#define UART_8bit_T1_FLOW_CONTROL                   (0u)

/* Check to see if required defines such as CY_PSOC3 and CY_PSOC5 are available */
/* They are defined starting with cy_boot v2.30 */
#ifndef CY_PSOC3
    #error Component UART_v2_10 requires cy_boot v2.30 or later
#endif /* End CY_PSOC3 */

#if(CY_PSOC3_ES2 && (UART_8bit_T1_RX_INTERRUPT_ENABLED || UART_8bit_T1_TX_INTERRUPT_ENABLED))
    #include <intrins.h>
    #define UART_8bit_T1_ISR_PATCH() _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_(); _nop_();
#endif /* End CY_PSOC3_ES2 */

#ifdef UART_8bit_T1_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG
    #define UART_8bit_T1_CONTROL_REG_REMOVED            (0u)
#else
    #define UART_8bit_T1_CONTROL_REG_REMOVED            (1u)
#endif /* End UART_8bit_T1_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG */


/***************************************
*      Data Struct Definition
***************************************/

/* Sleep Mode API Support */
typedef struct _UART_8bit_T1_backupStruct
{
    uint8 enableState;

    #if(UART_8bit_T1_CONTROL_REG_REMOVED == 0u)
        uint8 cr;            
    #endif /* End UART_8bit_T1_CONTROL_REG_REMOVED */    
    #if( (UART_8bit_T1_RX_ENABLED) || (UART_8bit_T1_HD_ENABLED) )
        uint8 rx_period;
        #if (CY_PSOC3_ES2 || CY_PSOC5_ES1) /* PSoC3 ES2 or early, PSoC5 ES1*/
            uint8 rx_mask;
            #if (UART_8bit_T1_RXHW_ADDRESS_ENABLED)
                uint8 rx_addr1;
                uint8 rx_addr2;
            #endif /* End UART_8bit_T1_RXHW_ADDRESS_ENABLED */
        #endif /* End PSOC3_ES2 || PSOC5_ES1 */
    #endif  /* End (UART_8bit_T1_RX_ENABLED) || (UART_8bit_T1_HD_ENABLED)*/

    #if(UART_8bit_T1_TX_ENABLED)
        #if(UART_8bit_T1_TXCLKGEN_DP)
            uint8 tx_clk_ctr;
            #if (CY_PSOC3_ES2 || CY_PSOC5_ES1) /* PSoC3 ES2 or early, PSoC5 ES1*/
                uint8 tx_clk_compl;
            #endif  /* End PSOC3_ES2 || PSOC5_ES1 */
        #else
            uint8 tx_period;
        #endif /*End UART_8bit_T1_TXCLKGEN_DP */
        #if (CY_PSOC3_ES2 || CY_PSOC5_ES1) /* PSoC3 ES2 or early, PSoC5 ES1*/
            uint8 tx_mask;
        #endif  /* End PSOC3_ES2 || PSOC5_ES1 */
    #endif /*End UART_8bit_T1_TX_ENABLED */
} UART_8bit_T1_BACKUP_STRUCT;


/***************************************
*       Function Prototypes
***************************************/

void UART_8bit_T1_Start(void) ;
void UART_8bit_T1_Stop(void) ;
uint8 UART_8bit_T1_ReadControlRegister(void) ;
void UART_8bit_T1_WriteControlRegister(uint8 control) ;

void UART_8bit_T1_Init(void) ;
void UART_8bit_T1_Enable(void) ;
void UART_8bit_T1_SaveConfig(void) ;
void UART_8bit_T1_RestoreConfig(void) ;
void UART_8bit_T1_Sleep(void) ;
void UART_8bit_T1_Wakeup(void) ;

/* Only if RX is enabled */
#if( (UART_8bit_T1_RX_ENABLED) || (UART_8bit_T1_HD_ENABLED) )

    #if(UART_8bit_T1_RX_INTERRUPT_ENABLED)
        void  UART_8bit_T1_EnableRxInt(void) ;
        void  UART_8bit_T1_DisableRxInt(void) ;
        CY_ISR_PROTO(UART_8bit_T1_RXISR);
    #endif /* UART_8bit_T1_RX_INTERRUPT_ENABLED */

    void UART_8bit_T1_SetRxAddressMode(uint8 addressMode) 
                                                           ;
    void UART_8bit_T1_SetRxAddress1(uint8 address) ;
    void UART_8bit_T1_SetRxAddress2(uint8 address) ;

    void  UART_8bit_T1_SetRxInterruptMode(uint8 intSrc) ;
    uint8 UART_8bit_T1_ReadRxData(void) ;
    uint8 UART_8bit_T1_ReadRxStatus(void) ;
    uint8 UART_8bit_T1_GetChar(void) ;
    uint16 UART_8bit_T1_GetByte(void) ;
    uint8 UART_8bit_T1_GetRxBufferSize(void)  
                                                            ;
    void UART_8bit_T1_ClearRxBuffer(void) ;

    /* Obsolete functions, defines for backward compatible */
    #define UART_8bit_T1_GetRxInterruptSource   UART_8bit_T1_ReadRxStatus

#endif /* End (UART_8bit_T1_RX_ENABLED) || (UART_8bit_T1_HD_ENABLED) */

/* Only if TX is enabled */
#if(UART_8bit_T1_TX_ENABLED || UART_8bit_T1_HD_ENABLED)

    #if(UART_8bit_T1_TX_INTERRUPT_ENABLED)
        void UART_8bit_T1_EnableTxInt(void) ;
        void UART_8bit_T1_DisableTxInt(void) ;
        CY_ISR_PROTO(UART_8bit_T1_TXISR);
    #endif /* UART_8bit_T1_TX_INTERRUPT_ENABLED */

    void UART_8bit_T1_SetTxInterruptMode(uint8 intSrc) ;
    void UART_8bit_T1_WriteTxData(uint8 txDataByte) ;
    uint8 UART_8bit_T1_ReadTxStatus(void) ;
    void UART_8bit_T1_PutChar(uint8 txDataByte) ;
    void UART_8bit_T1_PutString(char* string) ;
    void UART_8bit_T1_PutArray(uint8* string, uint8 byteCount)
                                                            ;
    void UART_8bit_T1_PutCRLF(uint8 txDataByte) ;
    void UART_8bit_T1_ClearTxBuffer(void) ;
    void UART_8bit_T1_SetTxAddressMode(uint8 addressMode) ;
    void UART_8bit_T1_SendBreak(uint8 retMode) ;
    uint8 UART_8bit_T1_GetTxBufferSize(void) 
                                                            ;
    /* Obsolete functions, defines for backward compatible */
    #define UART_8bit_T1_PutStringConst         UART_8bit_T1_PutString
    #define UART_8bit_T1_PutArrayConst          UART_8bit_T1_PutArray
    #define UART_8bit_T1_GetTxInterruptSource   UART_8bit_T1_ReadTxStatus
    
#endif /* End UART_8bit_T1_TX_ENABLED || UART_8bit_T1_HD_ENABLED */

#if(UART_8bit_T1_HD_ENABLED)
    void UART_8bit_T1_LoadRxConfig(void) ;
    void UART_8bit_T1_LoadTxConfig(void) ;
#endif /* End UART_8bit_T1_HD_ENABLED */


/***************************************
*          API Constants
***************************************/
/* Parameters for SetTxAddressMode API*/
#define UART_8bit_T1_SET_SPACE                              (0x00u)
#define UART_8bit_T1_SET_MARK                               (0x01u)

/* Status Register definitions */
#if( (UART_8bit_T1_TX_ENABLED) || (UART_8bit_T1_HD_ENABLED) )
    #if(UART_8bit_T1_TX_INTERRUPT_ENABLED)
        #define UART_8bit_T1_TX_VECT_NUM                UART_8bit_T1_TXInternalInterrupt__INTC_NUMBER
        #define UART_8bit_T1_TX_PRIOR_NUM               UART_8bit_T1_TXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* UART_8bit_T1_TX_INTERRUPT_ENABLED */
    #if(UART_8bit_T1_TX_ENABLED) 
        #define UART_8bit_T1_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define UART_8bit_T1_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define UART_8bit_T1_TX_STS_FIFO_FULL_SHIFT         (0x02u)
        #define UART_8bit_T1_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* UART_8bit_T1_TX_ENABLED */
    #if(UART_8bit_T1_HD_ENABLED) 
        #define UART_8bit_T1_TX_STS_COMPLETE_SHIFT          (0x00u)
        #define UART_8bit_T1_TX_STS_FIFO_EMPTY_SHIFT        (0x01u)
        #define UART_8bit_T1_TX_STS_FIFO_FULL_SHIFT         (0x05u)  /*needs MD=0*/
        #define UART_8bit_T1_TX_STS_FIFO_NOT_FULL_SHIFT     (0x03u)
    #endif /* UART_8bit_T1_HD_ENABLED */
    #define UART_8bit_T1_TX_STS_COMPLETE                (0x01u << UART_8bit_T1_TX_STS_COMPLETE_SHIFT)
    #define UART_8bit_T1_TX_STS_FIFO_EMPTY              (0x01u << UART_8bit_T1_TX_STS_FIFO_EMPTY_SHIFT)
    #define UART_8bit_T1_TX_STS_FIFO_FULL               (0x01u << UART_8bit_T1_TX_STS_FIFO_FULL_SHIFT)
    #define UART_8bit_T1_TX_STS_FIFO_NOT_FULL           (0x01u << UART_8bit_T1_TX_STS_FIFO_NOT_FULL_SHIFT)
#endif /* End (UART_8bit_T1_TX_ENABLED) || (UART_8bit_T1_HD_ENABLED)*/

#if( (UART_8bit_T1_RX_ENABLED) || (UART_8bit_T1_HD_ENABLED) )
    #if(UART_8bit_T1_RX_INTERRUPT_ENABLED)
        #define UART_8bit_T1_RX_VECT_NUM                UART_8bit_T1_RXInternalInterrupt__INTC_NUMBER
        #define UART_8bit_T1_RX_PRIOR_NUM               UART_8bit_T1_RXInternalInterrupt__INTC_PRIOR_NUM
    #endif /* UART_8bit_T1_RX_INTERRUPT_ENABLED */
    #define UART_8bit_T1_RX_STS_MRKSPC_SHIFT            (0x00u)
    #define UART_8bit_T1_RX_STS_BREAK_SHIFT             (0x01u)
    #define UART_8bit_T1_RX_STS_PAR_ERROR_SHIFT         (0x02u)
    #define UART_8bit_T1_RX_STS_STOP_ERROR_SHIFT        (0x03u)
    #define UART_8bit_T1_RX_STS_OVERRUN_SHIFT           (0x04u)
    #define UART_8bit_T1_RX_STS_FIFO_NOTEMPTY_SHIFT     (0x05u)
    #define UART_8bit_T1_RX_STS_ADDR_MATCH_SHIFT        (0x06u)
    #define UART_8bit_T1_RX_STS_SOFT_BUFF_OVER_SHIFT    (0x07u)

    #define UART_8bit_T1_RX_STS_MRKSPC                  (0x01u << UART_8bit_T1_RX_STS_MRKSPC_SHIFT)
    #define UART_8bit_T1_RX_STS_BREAK                   (0x01u << UART_8bit_T1_RX_STS_BREAK_SHIFT)
    #define UART_8bit_T1_RX_STS_PAR_ERROR               (0x01u << UART_8bit_T1_RX_STS_PAR_ERROR_SHIFT)
    #define UART_8bit_T1_RX_STS_STOP_ERROR              (0x01u << UART_8bit_T1_RX_STS_STOP_ERROR_SHIFT)
    #define UART_8bit_T1_RX_STS_OVERRUN                 (0x01u << UART_8bit_T1_RX_STS_OVERRUN_SHIFT)
    #define UART_8bit_T1_RX_STS_FIFO_NOTEMPTY           (0x01u << UART_8bit_T1_RX_STS_FIFO_NOTEMPTY_SHIFT)
    #define UART_8bit_T1_RX_STS_ADDR_MATCH              (0x01u << UART_8bit_T1_RX_STS_ADDR_MATCH_SHIFT)
    #define UART_8bit_T1_RX_STS_SOFT_BUFF_OVER          (0x01u << UART_8bit_T1_RX_STS_SOFT_BUFF_OVER_SHIFT)
    #define UART_8bit_T1_RX_HW_MASK                     (0x7Fu)
#endif /* End (UART_8bit_T1_RX_ENABLED) || (UART_8bit_T1_HD_ENABLED) */

/* Control Register definitions */
#define UART_8bit_T1_CTRL_HD_SEND_SHIFT                 (0x00u) /* 1 enable TX part in Half Duplex mode */
#define UART_8bit_T1_CTRL_HD_SEND_BREAK_SHIFT           (0x01u) /* 1 send BREAK signal in Half Duplez mode */
#define UART_8bit_T1_CTRL_MARK_SHIFT                    (0x02u) /* 1 sets mark, 0 sets space */
#define UART_8bit_T1_CTRL_PARITY_TYPE0_SHIFT            (0x03u) /* Defines the type of parity implemented */
#define UART_8bit_T1_CTRL_PARITY_TYPE1_SHIFT            (0x04u) /* Defines the type of parity implemented */
#define UART_8bit_T1_CTRL_RXADDR_MODE0_SHIFT            (0x05u)
#define UART_8bit_T1_CTRL_RXADDR_MODE1_SHIFT            (0x06u)
#define UART_8bit_T1_CTRL_RXADDR_MODE2_SHIFT            (0x07u)

#define UART_8bit_T1_CTRL_HD_SEND                       (0x01u << UART_8bit_T1_CTRL_HD_SEND_SHIFT)
#define UART_8bit_T1_CTRL_HD_SEND_BREAK                 (0x01u << UART_8bit_T1_CTRL_HD_SEND_BREAK_SHIFT)
#define UART_8bit_T1_CTRL_MARK                          (0x01u << UART_8bit_T1_CTRL_MARK_SHIFT)
#define UART_8bit_T1_CTRL_PARITY_TYPE_MASK              (0x03u << UART_8bit_T1_CTRL_PARITY_TYPE0_SHIFT)
#define UART_8bit_T1_CTRL_RXADDR_MODE_MASK              (0x07u << UART_8bit_T1_CTRL_RXADDR_MODE0_SHIFT)

/* StatusI Register Interrupt Enable Control Bits. As defined by the Register map for the AUX Control Register */
#define UART_8bit_T1_INT_ENABLE                         (0x10u)

/* Bit Counter (7-bit) Control Register Bit Definitions. As defined by the Register map for the AUX Control Register */
#define UART_8bit_T1_CNTR_ENABLE                        (0x20u)

/*   Constants for SendBreak() "retMode" parameter  */
#define UART_8bit_T1_SEND_BREAK                         (0x00u)
#define UART_8bit_T1_WAIT_FOR_COMPLETE_REINIT           (0x01u)
#define UART_8bit_T1_REINIT                             (0x02u)
#define UART_8bit_T1_SEND_WAIT_REINIT                   (0x03u)

#define UART_8bit_T1_OVER_SAMPLE_8                      (8u)
#define UART_8bit_T1_OVER_SAMPLE_16                     (16u)

#define UART_8bit_T1_BIT_CENTER                         (UART_8bit_T1_OVER_SAMPLE_COUNT - 1u)

#define UART_8bit_T1_FIFO_LENGTH                        (4u)
#define UART_8bit_T1_NUMBER_OF_START_BIT                (1u)

/* 8X always for count7 implementation*/
#define UART_8bit_T1_TXBITCTR_BREAKBITS8X   (UART_8bit_T1_BREAK_BITS_TX * UART_8bit_T1_OVER_SAMPLE_8 - 1u)
/* 8X or 16X for DP implementation*/
#define UART_8bit_T1_TXBITCTR_BREAKBITS   (UART_8bit_T1_BREAK_BITS_TX * UART_8bit_T1_OVER_SAMPLE_COUNT - 1u)

#if (UART_8bit_T1_OVER_SAMPLE_COUNT == UART_8bit_T1_OVER_SAMPLE_8)
    #define UART_8bit_T1_HD_TXBITCTR_INIT   ((UART_8bit_T1_BREAK_BITS_TX + \
        UART_8bit_T1_NUMBER_OF_START_BIT) * UART_8bit_T1_OVER_SAMPLE_COUNT - 1u)
    /* This parameter is increased on the 1 in 2 out of 3 mode to sample voting in the middle */
    #define UART_8bit_T1_HD_RXBITCTR_INIT   ((UART_8bit_T1_BREAK_BITS_RX + \
    UART_8bit_T1_NUMBER_OF_START_BIT) * UART_8bit_T1_OVER_SAMPLE_COUNT - 1u + \
    (UART_8bit_T1_OVER_SAMPLE_COUNT / 2u) + (UART_8bit_T1_USE23POLLING * 2u) - 1u)
#else /* UART_8bit_T1_OVER_SAMPLE_COUNT == UART_8bit_T1_OVER_SAMPLE_16 */
    #define UART_8bit_T1_HD_TXBITCTR_INIT   (8u * UART_8bit_T1_OVER_SAMPLE_COUNT - 1u)
    #define UART_8bit_T1_HD_RXBITCTR_INIT   (7u * UART_8bit_T1_OVER_SAMPLE_COUNT - 1u  +  \
       (UART_8bit_T1_OVER_SAMPLE_COUNT / 2u) + (UART_8bit_T1_USE23POLLING * 2u) - 1u)
#endif /* End UART_8bit_T1_OVER_SAMPLE_COUNT */


/***************************************
* Enumerated Types and Parameters
***************************************/

#define UART_8bit_T1__B_UART__AM_SW_BYTE_BYTE 1
#define UART_8bit_T1__B_UART__AM_SW_DETECT_TO_BUFFER 2
#define UART_8bit_T1__B_UART__AM_HW_BYTE_BY_BYTE 3
#define UART_8bit_T1__B_UART__AM_HW_DETECT_TO_BUFFER 4
#define UART_8bit_T1__B_UART__AM_NONE 0

#define UART_8bit_T1__B_UART__NONE_REVB 0
#define UART_8bit_T1__B_UART__EVEN_REVB 1
#define UART_8bit_T1__B_UART__ODD_REVB 2
#define UART_8bit_T1__B_UART__MARK_SPACE_REVB 3



/***************************************
*    Initial Parameter Constants
***************************************/

#define UART_8bit_T1_TXBUFFERSIZE           (4u)
#define UART_8bit_T1_RXBUFFERSIZE           (4u)
/* UART shifts max 8 bits, Mark/Space functionality working if 9 selected */
#define UART_8bit_T1_NUMBER_OF_DATA_BITS    ((8u > 8u) ? 8u : 8u)
#define UART_8bit_T1_NUMBER_OF_STOP_BITS    (1u)

#if (UART_8bit_T1_RXHW_ADDRESS_ENABLED)
    #define UART_8bit_T1_RXADDRESSMODE      (0u)
    #define UART_8bit_T1_RXHWADDRESS1       (0u)
    #define UART_8bit_T1_RXHWADDRESS2       (0u)
    /* Backward compatible define */
    #define UART_8bit_T1_RXAddressMode      UART_8bit_T1_RXADDRESSMODE
#endif /* End EnableHWAddress */

#define UART_8bit_T1_INIT_RX_INTERRUPTS_MASK \
                                          (1 << UART_8bit_T1_RX_STS_FIFO_NOTEMPTY_SHIFT) \
                                        | (0 << UART_8bit_T1_RX_STS_MRKSPC_SHIFT) \
                                        | (0 << UART_8bit_T1_RX_STS_ADDR_MATCH_SHIFT) \
                                        | (0 << UART_8bit_T1_RX_STS_PAR_ERROR_SHIFT) \
                                        | (0 << UART_8bit_T1_RX_STS_STOP_ERROR_SHIFT) \
                                        | (0 << UART_8bit_T1_RX_STS_BREAK_SHIFT) \
                                        | (0 << UART_8bit_T1_RX_STS_OVERRUN_SHIFT)

#define UART_8bit_T1_INIT_TX_INTERRUPTS_MASK \
                                          (1 << UART_8bit_T1_TX_STS_COMPLETE_SHIFT) \
                                        | (0 << UART_8bit_T1_TX_STS_FIFO_EMPTY_SHIFT) \
                                        | (0 << UART_8bit_T1_TX_STS_FIFO_FULL_SHIFT) \
                                        | (0 << UART_8bit_T1_TX_STS_FIFO_NOT_FULL_SHIFT)


/***************************************
*              Registers
***************************************/

#ifdef UART_8bit_T1_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG
    #define UART_8bit_T1_CONTROL_REG \
                            (* (reg8 *) UART_8bit_T1_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG )
    #define UART_8bit_T1_CONTROL_PTR \
                            (  (reg8 *) UART_8bit_T1_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG )
#endif /* End UART_8bit_T1_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG */

#if(UART_8bit_T1_TX_ENABLED)
    #define UART_8bit_T1_TXDATA_REG          (* (reg8 *) UART_8bit_T1_BUART_sTX_TxShifter_u0__F0_REG)
    #define UART_8bit_T1_TXDATA_PTR          (  (reg8 *) UART_8bit_T1_BUART_sTX_TxShifter_u0__F0_REG)
    #define UART_8bit_T1_TXDATA_AUX_CTL_REG  (* (reg8 *) UART_8bit_T1_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define UART_8bit_T1_TXDATA_AUX_CTL_PTR  (  (reg8 *) UART_8bit_T1_BUART_sTX_TxShifter_u0__DP_AUX_CTL_REG)
    #define UART_8bit_T1_TXSTATUS_REG        (* (reg8 *) UART_8bit_T1_BUART_sTX_TxSts__STATUS_REG)
    #define UART_8bit_T1_TXSTATUS_PTR        (  (reg8 *) UART_8bit_T1_BUART_sTX_TxSts__STATUS_REG)
    #define UART_8bit_T1_TXSTATUS_MASK_REG   (* (reg8 *) UART_8bit_T1_BUART_sTX_TxSts__MASK_REG)
    #define UART_8bit_T1_TXSTATUS_MASK_PTR   (  (reg8 *) UART_8bit_T1_BUART_sTX_TxSts__MASK_REG)
    #define UART_8bit_T1_TXSTATUS_ACTL_REG   (* (reg8 *) UART_8bit_T1_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)
    #define UART_8bit_T1_TXSTATUS_ACTL_PTR   (  (reg8 *) UART_8bit_T1_BUART_sTX_TxSts__STATUS_AUX_CTL_REG)

    /* DP clock */
    #if(UART_8bit_T1_TXCLKGEN_DP)
        #define UART_8bit_T1_TXBITCLKGEN_CTR_REG        \
                                        (* (reg8 *) UART_8bit_T1_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define UART_8bit_T1_TXBITCLKGEN_CTR_PTR        \
                                        (  (reg8 *) UART_8bit_T1_BUART_sTX_sCLOCK_TxBitClkGen__D0_REG)
        #define UART_8bit_T1_TXBITCLKTX_COMPLETE_REG    \
                                        (* (reg8 *) UART_8bit_T1_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
        #define UART_8bit_T1_TXBITCLKTX_COMPLETE_PTR    \
                                        (  (reg8 *) UART_8bit_T1_BUART_sTX_sCLOCK_TxBitClkGen__D1_REG)
    #else     /* Count7 clock*/
        #define UART_8bit_T1_TXBITCTR_PERIOD_REG    \
                                        (* (reg8 *) UART_8bit_T1_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define UART_8bit_T1_TXBITCTR_PERIOD_PTR    \
                                        (  (reg8 *) UART_8bit_T1_BUART_sTX_sCLOCK_TxBitCounter__PERIOD_REG)
        #define UART_8bit_T1_TXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) UART_8bit_T1_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define UART_8bit_T1_TXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) UART_8bit_T1_BUART_sTX_sCLOCK_TxBitCounter__CONTROL_AUX_CTL_REG)
        #define UART_8bit_T1_TXBITCTR_COUNTER_REG   \
                                        (* (reg8 *) UART_8bit_T1_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
        #define UART_8bit_T1_TXBITCTR_COUNTER_PTR   \
                                        (  (reg8 *) UART_8bit_T1_BUART_sTX_sCLOCK_TxBitCounter__COUNT_REG)
    #endif /* UART_8bit_T1_TXCLKGEN_DP */

#endif /* End UART_8bit_T1_TX_ENABLED */

#if(UART_8bit_T1_HD_ENABLED)

    #define UART_8bit_T1_TXDATA_REG             (* (reg8 *) UART_8bit_T1_BUART_sRX_RxShifter_u0__F1_REG )
    #define UART_8bit_T1_TXDATA_PTR             (  (reg8 *) UART_8bit_T1_BUART_sRX_RxShifter_u0__F1_REG )
    #define UART_8bit_T1_TXDATA_AUX_CTL_REG     (* (reg8 *) UART_8bit_T1_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)
    #define UART_8bit_T1_TXDATA_AUX_CTL_PTR     (  (reg8 *) UART_8bit_T1_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define UART_8bit_T1_TXSTATUS_REG           (* (reg8 *) UART_8bit_T1_BUART_sRX_RxSts__STATUS_REG )
    #define UART_8bit_T1_TXSTATUS_PTR           (  (reg8 *) UART_8bit_T1_BUART_sRX_RxSts__STATUS_REG )
    #define UART_8bit_T1_TXSTATUS_MASK_REG      (* (reg8 *) UART_8bit_T1_BUART_sRX_RxSts__MASK_REG )
    #define UART_8bit_T1_TXSTATUS_MASK_PTR      (  (reg8 *) UART_8bit_T1_BUART_sRX_RxSts__MASK_REG )
    #define UART_8bit_T1_TXSTATUS_ACTL_REG      (* (reg8 *) UART_8bit_T1_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define UART_8bit_T1_TXSTATUS_ACTL_PTR      (  (reg8 *) UART_8bit_T1_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End UART_8bit_T1_HD_ENABLED */

#if( (UART_8bit_T1_RX_ENABLED) || (UART_8bit_T1_HD_ENABLED) )
    #define UART_8bit_T1_RXDATA_REG             (* (reg8 *) UART_8bit_T1_BUART_sRX_RxShifter_u0__F0_REG )
    #define UART_8bit_T1_RXDATA_PTR             (  (reg8 *) UART_8bit_T1_BUART_sRX_RxShifter_u0__F0_REG )
    #define UART_8bit_T1_RXADDRESS1_REG         (* (reg8 *) UART_8bit_T1_BUART_sRX_RxShifter_u0__D0_REG )
    #define UART_8bit_T1_RXADDRESS1_PTR         (  (reg8 *) UART_8bit_T1_BUART_sRX_RxShifter_u0__D0_REG )
    #define UART_8bit_T1_RXADDRESS2_REG         (* (reg8 *) UART_8bit_T1_BUART_sRX_RxShifter_u0__D1_REG )
    #define UART_8bit_T1_RXADDRESS2_PTR         (  (reg8 *) UART_8bit_T1_BUART_sRX_RxShifter_u0__D1_REG )
    #define UART_8bit_T1_RXDATA_AUX_CTL_REG     (* (reg8 *) UART_8bit_T1_BUART_sRX_RxShifter_u0__DP_AUX_CTL_REG)

    #define UART_8bit_T1_RXBITCTR_PERIOD_REG    (* (reg8 *) UART_8bit_T1_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define UART_8bit_T1_RXBITCTR_PERIOD_PTR    (  (reg8 *) UART_8bit_T1_BUART_sRX_RxBitCounter__PERIOD_REG )
    #define UART_8bit_T1_RXBITCTR_CONTROL_REG   \
                                        (* (reg8 *) UART_8bit_T1_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define UART_8bit_T1_RXBITCTR_CONTROL_PTR   \
                                        (  (reg8 *) UART_8bit_T1_BUART_sRX_RxBitCounter__CONTROL_AUX_CTL_REG )
    #define UART_8bit_T1_RXBITCTR_COUNTER_REG   (* (reg8 *) UART_8bit_T1_BUART_sRX_RxBitCounter__COUNT_REG )
    #define UART_8bit_T1_RXBITCTR_COUNTER_PTR   (  (reg8 *) UART_8bit_T1_BUART_sRX_RxBitCounter__COUNT_REG )

    #define UART_8bit_T1_RXSTATUS_REG           (* (reg8 *) UART_8bit_T1_BUART_sRX_RxSts__STATUS_REG )
    #define UART_8bit_T1_RXSTATUS_PTR           (  (reg8 *) UART_8bit_T1_BUART_sRX_RxSts__STATUS_REG )
    #define UART_8bit_T1_RXSTATUS_MASK_REG      (* (reg8 *) UART_8bit_T1_BUART_sRX_RxSts__MASK_REG )
    #define UART_8bit_T1_RXSTATUS_MASK_PTR      (  (reg8 *) UART_8bit_T1_BUART_sRX_RxSts__MASK_REG )
    #define UART_8bit_T1_RXSTATUS_ACTL_REG      (* (reg8 *) UART_8bit_T1_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
    #define UART_8bit_T1_RXSTATUS_ACTL_PTR      (  (reg8 *) UART_8bit_T1_BUART_sRX_RxSts__STATUS_AUX_CTL_REG )
#endif /* End  (UART_8bit_T1_RX_ENABLED) || (UART_8bit_T1_HD_ENABLED) */

#if(UART_8bit_T1_INTERNAL_CLOCK_USED)
    /* Register to enable or disable the digital clocks */
    #define UART_8bit_T1_INTCLOCK_CLKEN_REG     (* (reg8 *) UART_8bit_T1_IntClock__PM_ACT_CFG)
    #define UART_8bit_T1_INTCLOCK_CLKEN_PTR     (  (reg8 *) UART_8bit_T1_IntClock__PM_ACT_CFG)

    /* Clock mask for this clock. */
    #define UART_8bit_T1_INTCLOCK_CLKEN_MASK    UART_8bit_T1_IntClock__PM_ACT_MSK
#endif /* End UART_8bit_T1_INTERNAL_CLOCK_USED */


/***************************************
*       Register Constants              
***************************************/

#if(UART_8bit_T1_TX_ENABLED)
    #define UART_8bit_T1_TX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End UART_8bit_T1_TX_ENABLED */

#if(UART_8bit_T1_HD_ENABLED)
    #define UART_8bit_T1_TX_FIFO_CLR            (0x02u) /* FIFO1 CLR */
#endif /* End UART_8bit_T1_HD_ENABLED */

#if( (UART_8bit_T1_RX_ENABLED) || (UART_8bit_T1_HD_ENABLED) )
    #define UART_8bit_T1_RX_FIFO_CLR            (0x01u) /* FIFO0 CLR */
#endif /* End  (UART_8bit_T1_RX_ENABLED) || (UART_8bit_T1_HD_ENABLED) */


/***************************************
* Renamed global variables or defines 
* for backward compatible
***************************************/

#define UART_8bit_T1_initvar                    UART_8bit_T1_initVar

#define UART_8bit_T1_RX_Enabled                 UART_8bit_T1_RX_ENABLED
#define UART_8bit_T1_TX_Enabled                 UART_8bit_T1_TX_ENABLED
#define UART_8bit_T1_HD_Enabled                 UART_8bit_T1_HD_ENABLED
#define UART_8bit_T1_RX_IntInterruptEnabled     UART_8bit_T1_RX_INTERRUPT_ENABLED
#define UART_8bit_T1_TX_IntInterruptEnabled     UART_8bit_T1_TX_INTERRUPT_ENABLED
#define UART_8bit_T1_InternalClockUsed          UART_8bit_T1_INTERNAL_CLOCK_USED
#define UART_8bit_T1_RXHW_Address_Enabled       UART_8bit_T1_RXHW_ADDRESS_ENABLED
#define UART_8bit_T1_OverSampleCount            UART_8bit_T1_OVER_SAMPLE_COUNT
#define UART_8bit_T1_ParityType                 UART_8bit_T1_PARITY_TYPE

#if( UART_8bit_T1_TX_ENABLED && (UART_8bit_T1_TXBUFFERSIZE > UART_8bit_T1_FIFO_LENGTH))
    #define UART_8bit_T1_TXBUFFER               UART_8bit_T1_txBuffer
    #define UART_8bit_T1_TXBUFFERREAD           UART_8bit_T1_txBufferRead 
    #define UART_8bit_T1_TXBUFFERWRITE          UART_8bit_T1_txBufferWrite 
#endif /* End UART_8bit_T1_TX_ENABLED */
#if( ( UART_8bit_T1_RX_ENABLED || UART_8bit_T1_HD_ENABLED ) && \
     (UART_8bit_T1_RXBUFFERSIZE > UART_8bit_T1_FIFO_LENGTH) )
    #define UART_8bit_T1_RXBUFFER               UART_8bit_T1_rxBuffer
    #define UART_8bit_T1_RXBUFFERREAD           UART_8bit_T1_rxBufferRead 
    #define UART_8bit_T1_RXBUFFERWRITE          UART_8bit_T1_rxBufferWrite 
    #define UART_8bit_T1_RXBUFFERLOOPDETECT     UART_8bit_T1_rxBufferLoopDetect
    #define UART_8bit_T1_RXBUFFER_OVERFLOW      UART_8bit_T1_rxBufferOverflow
#endif /* End UART_8bit_T1_RX_ENABLED */

#ifdef UART_8bit_T1_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG
    #define UART_8bit_T1_CONTROL                UART_8bit_T1_CONTROL_REG 
#endif /* End UART_8bit_T1_BUART_sCR_AsyncCtl_CtrlReg__CONTROL_REG */

#if(UART_8bit_T1_TX_ENABLED)
    #define UART_8bit_T1_TXDATA                 UART_8bit_T1_TXDATA_REG
    #define UART_8bit_T1_TXSTATUS               UART_8bit_T1_TXSTATUS_REG
    #define UART_8bit_T1_TXSTATUS_MASK          UART_8bit_T1_TXSTATUS_MASK_REG   
    #define UART_8bit_T1_TXSTATUS_ACTL          UART_8bit_T1_TXSTATUS_ACTL_REG
    /* DP clock */
    #if(UART_8bit_T1_TXCLKGEN_DP)
        #define UART_8bit_T1_TXBITCLKGEN_CTR        UART_8bit_T1_TXBITCLKGEN_CTR_REG
        #define UART_8bit_T1_TXBITCLKTX_COMPLETE    UART_8bit_T1_TXBITCLKTX_COMPLETE_REG
    #else     /* Count7 clock*/
        #define UART_8bit_T1_TXBITCTR_PERIOD        UART_8bit_T1_TXBITCTR_PERIOD_REG
        #define UART_8bit_T1_TXBITCTR_CONTROL       UART_8bit_T1_TXBITCTR_CONTROL_REG
        #define UART_8bit_T1_TXBITCTR_COUNTER       UART_8bit_T1_TXBITCTR_COUNTER_REG
    #endif /* UART_8bit_T1_TXCLKGEN_DP */
#endif /* End UART_8bit_T1_TX_ENABLED */

#if(UART_8bit_T1_HD_ENABLED)
    #define UART_8bit_T1_TXDATA                 UART_8bit_T1_TXDATA_REG
    #define UART_8bit_T1_TXSTATUS               UART_8bit_T1_TXSTATUS_REG
    #define UART_8bit_T1_TXSTATUS_MASK          UART_8bit_T1_TXSTATUS_MASK_REG   
    #define UART_8bit_T1_TXSTATUS_ACTL          UART_8bit_T1_TXSTATUS_ACTL_REG
#endif /* End UART_8bit_T1_HD_ENABLED */

#if( (UART_8bit_T1_RX_ENABLED) || (UART_8bit_T1_HD_ENABLED) )
    #define UART_8bit_T1_RXDATA                 UART_8bit_T1_RXDATA_REG             
    #define UART_8bit_T1_RXADDRESS1             UART_8bit_T1_RXADDRESS1_REG
    #define UART_8bit_T1_RXADDRESS2             UART_8bit_T1_RXADDRESS2_REG
    #define UART_8bit_T1_RXBITCTR_PERIOD        UART_8bit_T1_RXBITCTR_PERIOD_REG
    #define UART_8bit_T1_RXBITCTR_CONTROL       UART_8bit_T1_RXBITCTR_CONTROL_REG
    #define UART_8bit_T1_RXBITCTR_COUNTER       UART_8bit_T1_RXBITCTR_COUNTER_REG
    #define UART_8bit_T1_RXSTATUS               UART_8bit_T1_RXSTATUS_REG
    #define UART_8bit_T1_RXSTATUS_MASK          UART_8bit_T1_RXSTATUS_MASK_REG
    #define UART_8bit_T1_RXSTATUS_ACTL          UART_8bit_T1_RXSTATUS_ACTL_REG
#endif /* End  (UART_8bit_T1_RX_ENABLED) || (UART_8bit_T1_HD_ENABLED) */

#if(UART_8bit_T1_INTERNAL_CLOCK_USED)
    #define UART_8bit_T1_INTCLOCK_CLKEN         UART_8bit_T1_INTCLOCK_CLKEN_REG
#endif /* End UART_8bit_T1_INTERNAL_CLOCK_USED */

#define UART_8bit_T1_WAIT_FOR_COMLETE_REINIT    UART_8bit_T1_WAIT_FOR_COMPLETE_REINIT

#endif  /* CY_UART_UART_8bit_T1_H */


/* [] END OF FILE */
