/* ===========================================================
 * 
 * Firmware for 8051 Emulation on PSoC 5 for MIT 6.115, 6.131
 *
 * Copyright Cypress Semiconductor, 2012
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF Cypress Semiconductor.
 *
 * ===========================================================
*/

#include <device.h>
#include <stdio.h>
#include <stdlib.h>
#include "stack.h"
#include "opcodes.h"
#include "comb_decomp.h"
#include "write_read_sfr.h"
#include "bit_addressable.h"
#include "sfrs.h"
#include "instructions.h"
#include "next_ROM.h"

#define bit_addressable_table_max	0xF7
#define PROGRAM_SIZE	(32*1024)

uint8 Program8051[PROGRAM_SIZE];
volatile const uint8 *Program8051Flash = (uint8 *)((256-32)*1024);
int syncPc = 0;
volatile uint16 globalPc = 0;
uint8 InternalRAM[0xFF];			/* Arrays store values of each location/register */
uint8 ExternalRAM[0x2000];
uint8 InternalRAM_indirect[0x80];  // Implement this space for @R0,@R1 instructions
uint8 bit_addressable_table[bit_addressable_table_max + 1];
int EA_flag;


void main()
{
	uint32 i;
	
	//Clock_2_Stop();	//change this
	Clock_9_Stop();
	
	CyGlobalIntEnable;
	
	init_bit_addressable();
	
	EA_flag = EA_Read();
	
	if (EA_flag) {
		for (i = 0; i < PROGRAM_SIZE; i++)
			Program8051[i] = Program8051Flash[i];
	}
	else {
		for (i = 0; i < PROGRAM_SIZE; i++)
			Program8051[i] = next_ex_ROM();
		globalPc = 0;
	}
	
	sp = 0x08;	// initialize stack pointer

	ProgramLoop();
}

/* [] END OF FILE */